@@ -1,11 +1,12 @@
-from distutils.dir_util import copy_tree
 from ..utils.utils import resource_path
 from ..model.export_avatar_params import ExportAvatarParams
 import os
 import json
+import zipfile
 import win32com.shell.shell as shell
 
 TASK_PARAMS_FILE_NAME = 'nowyou_task_params.txt'
+PLUGIN_PATH_NAME = 'Avatar_export'
 
 
 def export_avatar(
@@ -16,8 +17,10 @@ def export_avatar(
 ) -> str:
 
     # copy plugin script to VStitcher folder
-    plugin_path = os.path.join(vstitcher_data_path, 'Plugins\\Avatar_export')
-    copy_tree(resource_path('\\vstitcher_plugins\\avatar_export'), plugin_path)
+    with zipfile.ZipFile(resource_path('\\vstitcher_plugins\\avatar_export.zip'), 'r') as zip_ref:
+        plugin_path = os.path.join(vstitcher_data_path, 'Plugins')
+        # os.mkdir(plugin_path)
+        zip_ref.extractall(plugin_path)
 
     # set up task params
     params = ExportAvatarParams(body_sizes, work_path)
